@@ -31,6 +31,8 @@
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
+from __future__ import annotations
+
 import copy
 import csv
 import io
@@ -41,6 +43,7 @@ import re
 import textwrap
 from html import escape
 from html.parser import HTMLParser
+from typing import Any
 
 import wcwidth
 
@@ -558,11 +561,11 @@ class PrettyTable:
     # ATTRIBUTE MANAGEMENT       #
     ##############################
     @property
-    def rows(self):
+    def rows(self) -> list[Any]:
         return self._rows[:]
 
     @property
-    def xhtml(self):
+    def xhtml(self) -> bool:
         """Print <br/> tags if True, <br> tags if False"""
         return self._xhtml
 
@@ -1265,7 +1268,7 @@ class PrettyTable:
     # PRESET STYLE LOGIC         #
     ##############################
 
-    def set_style(self, style):
+    def set_style(self, style) -> None:
 
         if style == DEFAULT:
             self._set_default_style()
@@ -1385,7 +1388,7 @@ class PrettyTable:
     # DATA INPUT METHODS         #
     ##############################
 
-    def add_rows(self, rows):
+    def add_rows(self, rows) -> None:
 
         """Add rows to the table
 
@@ -1396,7 +1399,7 @@ class PrettyTable:
         for row in rows:
             self.add_row(row)
 
-    def add_row(self, row):
+    def add_row(self, row) -> None:
 
         """Add a row to the table
 
@@ -1414,7 +1417,7 @@ class PrettyTable:
             self.field_names = [f"Field {n + 1}" for n in range(0, len(row))]
         self._rows.append(list(row))
 
-    def del_row(self, row_index):
+    def del_row(self, row_index) -> None:
 
         """Delete a row from the table
 
@@ -1429,7 +1432,9 @@ class PrettyTable:
             )
         del self._rows[row_index]
 
-    def add_column(self, fieldname, column, align="c", valign="t"):
+    def add_column(
+        self, fieldname, column, align: str = "c", valign: str = "t"
+    ) -> None:
 
         """Add a column to the table.
 
@@ -1459,7 +1464,7 @@ class PrettyTable:
                 f"{len(self._rows)}"
             )
 
-    def add_autoindex(self, fieldname="Index"):
+    def add_autoindex(self, fieldname: str = "Index"):
         """Add an auto-incrementing index column to the table.
         Arguments:
         fieldname - name of the field to contain the new column of data"""
@@ -1469,7 +1474,7 @@ class PrettyTable:
         for i, row in enumerate(self._rows):
             row.insert(0, i + 1)
 
-    def del_column(self, fieldname):
+    def del_column(self, fieldname) -> None:
 
         """Delete a column from the table
 
@@ -1489,13 +1494,13 @@ class PrettyTable:
         for row in self._rows:
             del row[col_index]
 
-    def clear_rows(self):
+    def clear_rows(self) -> None:
 
         """Delete all rows from the table but keep the current field names"""
 
         self._rows = []
 
-    def clear(self):
+    def clear(self) -> None:
 
         """Delete all rows and field names from the table, maintaining nothing but
         styling options"""
@@ -1639,7 +1644,7 @@ class PrettyTable:
     # PLAIN TEXT STRING METHODS  #
     ##############################
 
-    def get_string(self, **kwargs):
+    def get_string(self, **kwargs) -> str:
 
         """Return string representation of table in current state.
 
@@ -1967,7 +1972,7 @@ class PrettyTable:
 
         return "\n".join(bits)
 
-    def paginate(self, page_length=58, line_break="\f", **kwargs):
+    def paginate(self, page_length: int = 58, line_break: str = "\f", **kwargs):
 
         pages = []
         kwargs["start"] = kwargs.get("start", 0)
@@ -1983,7 +1988,7 @@ class PrettyTable:
     ##############################
     # CSV STRING METHODS         #
     ##############################
-    def get_csv_string(self, **kwargs):
+    def get_csv_string(self, **kwargs) -> str:
 
         """Return string representation of CSV formatted table in the current state
 
@@ -2011,7 +2016,7 @@ class PrettyTable:
     ##############################
     # JSON STRING METHODS        #
     ##############################
-    def get_json_string(self, **kwargs):
+    def get_json_string(self, **kwargs) -> str:
 
         """Return string representation of JSON formatted table in the current state
 
@@ -2040,7 +2045,7 @@ class PrettyTable:
     # HTML STRING METHODS        #
     ##############################
 
-    def get_html_string(self, **kwargs):
+    def get_html_string(self, **kwargs) -> str:
         """Return string representation of HTML formatted version of table in current
         state.
 
@@ -2225,7 +2230,7 @@ class PrettyTable:
     # LATEX STRING METHODS       #
     ##############################
 
-    def get_latex_string(self, **kwargs):
+    def get_latex_string(self, **kwargs) -> str:
         """Return string representation of LaTex formatted version of table in current
         state.
 
@@ -2359,7 +2364,7 @@ def _str_block_width(val):
 ##############################
 
 
-def from_csv(fp, field_names=None, **kwargs):
+def from_csv(fp, field_names: Any | None = None, **kwargs):
     fmtparams = {}
     for param in [
         "delimiter",
@@ -2424,7 +2429,7 @@ class TableHandler(HTMLParser):
         self.is_last_row_header = False
         self.colspan = 0
 
-    def handle_starttag(self, tag, attrs):
+    def handle_starttag(self, tag, attrs) -> None:
         self.active = tag
         if tag == "th":
             self.is_last_row_header = True
@@ -2432,7 +2437,7 @@ class TableHandler(HTMLParser):
             if key == "colspan":
                 self.colspan = int(value)
 
-    def handle_endtag(self, tag):
+    def handle_endtag(self, tag) -> None:
         if tag in ["th", "td"]:
             stripped_content = self.last_content.strip()
             self.last_row.append(stripped_content)
@@ -2453,7 +2458,7 @@ class TableHandler(HTMLParser):
         self.last_content = " "
         self.active = None
 
-    def handle_data(self, data):
+    def handle_data(self, data) -> None:
         self.last_content += data
 
     def generate_table(self, rows):
@@ -2474,7 +2479,7 @@ class TableHandler(HTMLParser):
                 table.add_row(row[0])
         return table
 
-    def make_fields_unique(self, fields):
+    def make_fields_unique(self, fields) -> None:
         """
         iterates over the row and make each field unique
         """
